@@ -5,7 +5,7 @@ use Test::Builder::Module;
 use Test::Name::FromLine;
 use Text::MatchedPosition;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 our @ISA = qw/Test::Builder::Module/;
 
@@ -57,7 +57,12 @@ sub _import_option_binary {
 }
 
 sub new {
-    bless {}, shift;
+    my $class = shift;
+    my %args  = @_;
+
+    bless {
+        no_x => delete $args{'no_x'},
+    }, $class;
 }
 
 sub _tb { __PACKAGE__->builder }
@@ -221,6 +226,22 @@ sub explain {
     $self;
 }
 
+sub x {
+    my $self = shift;
+
+    return $self if $self->{no_x};
+
+    my $hash = {
+        got      => $self->{_got},
+        expected => $self->{_expected},
+        name     => $self->{_name},
+    };
+
+    $self->diag(_tb->explain(@_, $hash));
+
+    $self;
+}
+
 sub done_testing {
     my $self = shift;
 
@@ -487,7 +508,6 @@ Test::Arrow - Object-Oriented testing library
 
     my $arr = Test::Arrow->new;
 
-    $arr->ok(1);
     $arr->got(1)->ok;
 
     $arr->expect(uc 'foo')->to_be('FOO');
@@ -505,17 +525,6 @@ Test::Arrow - Object-Oriented testing library
         ->got('abc')
         ->like;
 
-    # `unlike` shows where a place could have matched if it's failed
-    $arr->name('Unlike Fail example')
-        ->expected(qr/b/)
-        ->got('abc')
-        ->unlike;
-    #   Failed test 'Unlike Fail example'
-    #   at t/unlike.t line 12.
-    #                   'abc'
-    #           matches '(?^:b)'
-    #           matched at line: 1, offset: 2
-
     $arr->warnings(sub { warn 'Bar' })->catch(qr/^Ba/);
     $arr->throw(sub { die 'Baz' })->catch(qr/^Ba/);
 
@@ -556,6 +565,14 @@ The constructor.
 
     my $arr = Test::Arrow->new;
 
+=over
+
+=item no_x
+
+If you set C<no_x> option the ture value, then the C<x> method doesn't show any message.
+
+=back
+
 =head2 SETTERS
 
 =head3 expected($expected)
@@ -615,7 +632,7 @@ More easy,
 
 Similar to C<is> and C<isnt> compare values with C<eq> and C<ne>.
 
-    $arr->expect('FOO')->got(uc 'foo')->is;
+    $arr->expected('FOO')->got(uc 'foo')->is;
 
 =head3 is_num
 
@@ -623,7 +640,7 @@ Similar to C<is> and C<isnt> compare values with C<eq> and C<ne>.
 
 Similar to C<is_num> and C<isnt_num> compare values with C<==> and C<!=>.
 
-    $arr->expect(6)->got( 2 * 3 )->is_num;
+    $arr->expected(6)->got( 2 * 3 )->is_num;
 
 =head3 to_be($got)
 
@@ -637,7 +654,21 @@ The $got will be compare with expected value.
 
 C<like> matches $got value against the $expected regex.
 
-    $arr->expect(qr/b/)->got('abc')->like;
+    $arr->expected(qr/b/)->got('abc')->like;
+
+Works exactly as C<like>, only it checks if $got does not match the expected pattern.
+
+C<unlike> shows where a place could have matched if it's failed like below.
+
+    $arr->name('Unlike Fail example')
+        ->expected(qr/b/)
+        ->got('abc')
+        ->unlike;
+    #   Failed test 'Unlike Fail example'
+    #   at t/unlike.t line 12.
+    #                   'abc'
+    #           matches '(?^:b)'
+    #           matched at line: 1, offset: 2
 
 =head3 can_ok($class, @methods)
 
@@ -742,6 +773,20 @@ If you call C<explain> method with arg, then C<explain> method just dumps it.
     # }
     ok 1 - foo
 
+=head3 x($ref)
+
+If you call C<x> method, then the current values (name, expected and got) are dumped with arg.
+
+    $arr->name('x test')->expected('BAR')->got(uc 'bar')->x({ foo => 123 })->is;
+    # {
+    #   'foo' => 123
+    # }
+    # {
+    #   'expected' => 'BAR',
+    #   'got' => 'BAR',
+    #   'name' => 'x test'
+    # }
+
 =head3 done_testing
 
 Declare of done testing.
@@ -766,7 +811,7 @@ Alias of C<done_testing>
 
 =begin html
 
-<a href="https://github.com/bayashi/Test-Arrow/blob/master/README.pod"><img src="https://img.shields.io/badge/Version-0.11-green?style=flat"></a> <a href="https://github.com/bayashi/Test-Arrow/blob/master/LICENSE"><img src="https://img.shields.io/badge/LICENSE-Artistic%202.0-GREEN.png"></a> <a href="https://github.com/bayashi/Test-Arrow/actions"><img src="https://github.com/bayashi/Test-Arrow/workflows/master/badge.svg?_t=1582822443"/></a> <a href="https://coveralls.io/r/bayashi/Test-Arrow"><img src="https://coveralls.io/repos/bayashi/Test-Arrow/badge.png?_t=1582822443&branch=master"/></a>
+<a href="https://github.com/bayashi/Test-Arrow/blob/master/README.pod"><img src="https://img.shields.io/badge/Version-0.12-green?style=flat"></a> <a href="https://github.com/bayashi/Test-Arrow/blob/master/LICENSE"><img src="https://img.shields.io/badge/LICENSE-Artistic%202.0-GREEN.png"></a> <a href="https://github.com/bayashi/Test-Arrow/actions"><img src="https://github.com/bayashi/Test-Arrow/workflows/master/badge.svg?_t=1582871423"/></a> <a href="https://coveralls.io/r/bayashi/Test-Arrow"><img src="https://coveralls.io/repos/bayashi/Test-Arrow/badge.png?_t=1582871423&branch=master"/></a>
 
 =end html
 
